@@ -1,12 +1,12 @@
 from fastapi import Header, Query
 
 from insnail_ai_tools.web import create_fast_api_app
-from insnail_ai_tools.web.sso_decorator import register_middleware
+from insnail_ai_tools.web.sso_decorator import Sso
 
 app = create_fast_api_app()
+sso = Sso("redis://@localhost:6379/1")
 
-
-register_middleware(app)
+sso.register_middleware(app)
 
 
 @app.get("/")
